1.0.0 API documentation: GLM_GTX_log_base

| 1.0.0 API documentation

Functions
GLM_GTX_log_base
Experimental extensions

## Functions
template<typename genType >
GLM_FUNC_DECL genType | log (genType const &x, genType const &base)
| Logarithm for any base. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | sign (vec< L, T, Q > const &x, vec< L, T, Q > const &base)
| Logarithm for any base. More...

## Detailed Description

Include <glm/gtx/log_base.hpp> to use the features of this extension.

Logarithm for any base. base can be a vector or a scalar.

## Function Documentation

## ◆ log()

GLM_FUNC_DECL genType glm::log | ( | genType const & | x,
|  | genType const & | base
| ) |  |

Logarithm for any base.

From GLM_GTX_log_base.

## ◆ sign()

GLM_FUNC_DECL vec<L, T, Q> glm::sign | ( | vec< L, T, Q > const & | x,
|  | vec< L, T, Q > const & | base
| ) |  |

Logarithm for any base.

From GLM_GTX_log_base.